@@ -41,6 +41,10 @@ class Secret(ReloadableObjectFromJson):
     def _parse_json_object(self, json_object: Dict[str, Any]) -> SecretInspectResult:
         return SecretInspectResult.parse_obj(json_object)
 
+    def _get_inspect_result(self) -> SecretInspectResult:
+        """Only there to allow tools to know the return type"""
+        return super()._get_inspect_result()
+
     @property
     def id(self) -> str:
         return self._get_immutable_id()
